from wagtail.blocks import (
    CharBlock,
    ChoiceBlock,
    ListBlock,
    StreamBlock,
    StructBlock,
)

from wagtail_cblocks.blocks import (
    ColumnsBlock,
    HeadingBlock,
    ImageBlock,
    LinkBlock,
)
from wagtail_footnotes.blocks import RichTextBlockWithFootnotes


class BaseBlock(StreamBlock):
    title_block = HeadingBlock()
    paragraph_block = RichTextBlockWithFootnotes(
        features=(
            'bold',
            'italic',
            'ol',
            'ul',
            'hr',
            'link',
            'document-link',
            'footnotes',
        ),
        label="Paragraphe",
    )
    image_block = ImageBlock()


class LayoutBaseBlock(BaseBlock):
    columns_block = ColumnsBlock(BaseBlock())


class EncartBlock(StructBlock):
    contenu = LayoutBaseBlock()
    couleur = ChoiceBlock(
        [
            ('red', 'Rouge'),
            ('grey', 'Gris'),
        ]
    )

    class Meta:
        icon = 'placeholder'
        label = 'Encart'
        template = 'blocks/encart_block.html'


class BodyBlock(LayoutBaseBlock):
    encart_block = EncartBlock()


class ImageLinkBlock(StructBlock):
    image = ImageBlock()
    lien = LinkBlock()

    class Meta:
        icon = 'image'
        label = 'Image cliquable'
        template = 'blocks/image_link_block.html'


class TextLinkBlock(StructBlock):
    texte = CharBlock()
    lien = LinkBlock()

    class Meta:
        label = 'Lien'
        template = 'blocks/link_block.html'


class ListLinksBlock(StructBlock):
    """Un titre suivi d'une liste de liens"""

    title = CharBlock(label="Titre", required=True)
    links = ListBlock(TextLinkBlock(), label='Liens')
