import re

import pytest
from bs4 import BeautifulSoup

from labrique.core.models import Numero

from .factories import ArticleFactory


def get_soup(content):
    return BeautifulSoup(content, 'html.parser')


@pytest.mark.django_db
class TestNumero:
    def test_get_last_num_no_num(self):
        assert Numero.get_last_num() == 0

    def test_get_last_num(self, numeros):
        assert Numero.get_last_num() == 2


@pytest.mark.django_db
class TestArticle:
    def test_is_void(self):
        assert ArticleFactory.create().is_void() is False

    def test_is_not_void(self):
        assert ArticleFactory.create(chapeau='', body='').is_void() is True


@pytest.mark.django_db
class TestHomePage:
    def test_get_last_numeros(self, client, home_page, numeros):
        response = client.get(home_page.url)
        links = get_soup(response.content).select('a', string=r'N°')
        for num in [f'N°{n.journal_numero}' for n in numeros]:
            assert num in ''.join([link.text for link in links])

    def test_get_paginated_articles(self, client, numeros, home_page):
        ArticleFactory.create_batch(10, parent=numeros[0])
        ArticleFactory.create_batch(12, parent=numeros[1])
        response = client.get(f'{home_page.url}?page=1')
        soup = get_soup(response.content)
        article_links = soup.find_all('a', string=re.compile("Lire la suite"))
        assert len(article_links) == 9
        next_page_link = soup.find_all('a', string="Suivant")
        assert len(next_page_link) == 1
