from django.core.exceptions import ValidationError

import pytest

from labrique.core.validators import RangePageValidator


class TestRagePageValidator:
    validate_page = RangePageValidator()

    @pytest.mark.parametrize('page_number', ['1', '42', '1984'])
    def test_one_page(self, page_number):
        assert self.validate_page(page_number) is None

    @pytest.mark.parametrize(
        'page_range', ['1-2', '42-43', '1-99999999999999']
    )
    def test_valid_range_page(self, page_range):
        assert self.validate_page(page_range) is None

    @pytest.mark.parametrize('page_range', ['-', '-2', '2-', '-1-1', 'spam'])
    def test_invalid_range_page(self, page_range):
        with pytest.raises(ValidationError):
            self.validate_page(page_range)

    @pytest.mark.parametrize('page_range', ['42-1', '1-0'])
    def test_range_page_not_increasing(self, page_range):
        with pytest.raises(ValidationError) as exc_info:
            self.validate_page(page_range)
        assert exc_info.value.args[0] == (
            'La première page doit être inférieure à la dernière'
        )
